@@ -11,23 +11,28 @@ class ColorFormatter(logging.Formatter):
     """Logging Formatter to add colors and count warning / errors"""
     def __init__(self, fmt=None, datefmt=None, style='%'):
         super().__init__(fmt, datefmt, style)
+        self.fmt = fmt
 
-        grey = "\033[38m"
-        yellow = "\033[93m"
-        red = "\033[91m"
-        bold_red = "\033[91;1m"
+        light_gray='\033[0;37m'
+        dark_gray='\033[1;30m'
+        yellow = "\033[0;33m"
+        red = "\033[0;31m"
         reset = "\033[0m"
 
         self.FORMATS = {
-            logging.DEBUG: grey + fmt + reset,
-            logging.INFO: grey + fmt + reset,
+            logging.DEBUG: dark_gray + fmt + reset,
+            logging.INFO: light_gray + fmt + reset,
             logging.WARNING: yellow + fmt + reset,
             logging.ERROR: red + fmt + reset,
-            logging.CRITICAL: bold_red + fmt + reset
         }
 
     def format(self, record):
-        log_fmt = self.FORMATS.get(record.levelno)
+        log_fmt = None
+        # if not windows, add color info
+        if sys.platform.lower() != 'win32':
+            log_fmt = self.FORMATS.get(record.levelno)
+        if log_fmt is None:
+            log_fmt = self.fmt
         formatter = logging.Formatter(log_fmt)
         return formatter.format(record)
 
