@@ -10,7 +10,7 @@ from fissix import pytree
 from fissix.pygram import python_grammar, python_symbols
 from fissix.pgen2 import token
 from fissix.pytree import Leaf, Node
-from fissix.fixer_util import Attr, Comma, Dot, LParen, Name, Newline, RParen, KeywordArg, Number, ArgList, Newline
+from fissix.fixer_util import Attr, Comma, Dot, LParen, Name, Newline, RParen, KeywordArg, Number, ArgList
 
 from paddle1to2.common import logger
 
@@ -143,7 +143,7 @@ def add_argument(filename, trailer_node, key, value):
                 _value_node_copy.type = token.NAME
                 _value_node_copy.value = value
                 _value_node.replace(_value_node_copy)
-                log_warning(filename, arglist_node.get_lineno(), 'argument "{}" is reassigned to "{}"'.format(key, value))
+                log_warning(filename, trailer_node.get_lineno(), 'argument "{}" is reassigned to "{}"'.format(key, value))
             break
     if not found_key:
         key_node = Name(key)
@@ -153,7 +153,7 @@ def add_argument(filename, trailer_node, key, value):
             key_node.prefix = " "
         arg_node = KeywordArg(key_node, value_node)
         arglist_node.append_child(arg_node)
-        log_warning(filename, arglist_node.get_lineno(), 'add argument "{}={}"'.format(key, value))
+        log_warning(filename, trailer_node.get_lineno(), 'add argument "{}={}"'.format(key, value))
 
 
 def remove_argument(filename, trailer_node, key):
@@ -175,17 +175,16 @@ def remove_argument(filename, trailer_node, key):
         _key_node = node.children[0]
         if _key_node.value == key:
             found_key = True
-            removed_value = node.children[2].value if len(node.children) >= 3 else None
+            removed_value = node2code(node.children[2]) if len(node.children) >= 3 else None
             if node.prev_sibling is not None and node.prev_sibling.type is token.COMMA:
                 node.prev_sibling.remove()
             elif node.next_sibling is not None and node.next_sibling.type is token.COMMA:
                 node.next_sibling.remove()
-            lineno = arglist_node.get_lineno()
             node.remove()
-            log_warning(filename, lineno, 'argument "{}" is removed.'.format(key))
+            log_warning(filename, trailer_node.get_lineno(), 'argument "{}" is removed.'.format(key))
             break
     if not found_key:
-        log_info(filename, arglist_node.get_lineno(), 'argument "{}" not found.'.format(key))
+        log_info(filename, trailer_node.get_lineno(), 'argument "{}" not found.'.format(key))
     return removed_value
 
 
@@ -208,10 +207,10 @@ def rename_argument(filename, trailer_node, old_key, new_key):
         if _key_node.value == old_key:
             found_key = True
             _key_node.value = new_key
-            log_warning(filename, arglist_node.get_lineno(), 'rename argument "{}" to "{}".'.format(old_key, new_key))
+            log_warning(filename, trailer_node.get_lineno(), 'rename argument "{}" to "{}".'.format(old_key, new_key))
             break
     if not found_key:
-        log_info(filename, arglist_node.get_lineno(), 'argument "{}" not found.'.format(old_key))
+        log_info(filename, trailer_node.get_lineno(), 'argument "{}" not found.'.format(old_key))
 
 
 def apply_argument(filename, trailer_node, fun):
@@ -397,3 +396,57 @@ def insert_node_behind(node1, nodes):
                 if node is not None:
                     node1.parent.insert_child(idx, node)
                     idx += 1
+
+_newline_node = None
+def newline_node(node):
+    """
+    Find a NEWLINE node from AST tree, and clone it to create a new NEWLINE node.
+    So we don't need to care about os platform.
+    if no NEWLINE node found in AST tree, create a new NEWLINE node according to os platform.
+    """
+    global _newline_node
+    if _newline_node is None:
+        p = node
+        while p is not None and p.parent is not None:
+            p = p.parent
+        if p is not None:
+            for leaf in p.leaves():
+                if leaf.type == token.NEWLINE:
+                    _newline_node = leaf
+                    break
+        if _newline_node is None:
+            if is_windows:
+                _newline_node = Newline(value="\r\n")
+            else:
+                _newline_node = Newline()
+    return _newline_node.clone()
+
+def is_import_node(node):
+    """
+    check if a node is an import node
+    """
+    p = node
+    while p is not None:
+        if p.type in {python_symbols.import_name, python_symbols.import_from}:
+            return True
+        p = p.parent
+    return False
+
+def is_argument_node(node):
+    """
+    check if a node is a argument node
+    """
+    p = node
+    while p is not None:
+        if p.type == python_symbols.argument:
+            return True
+        p = p.parent
+    return False
+
+def is_left_operand(node):
+    """
+    check if a node is left operand
+    """
+    if node is not None and node.next_sibling is not None and node.next_sibling.type is token.EQUAL:
+        return True
+    return False
